@@ -33,17 +33,18 @@ G_BEGIN_DECLS
 /* EphyWebView */
 
 #define EPHY_WEB_VIEW_NON_SEARCH_REGEX  "(" \
-                                        "^localhost(\\.[^[:space:]]+)?(:\\d+)?(/.*)?$|" \
-                                        "^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]$|" \
+                                        "^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9](:[0-9]+)?.*$|" \
                                         "^::[0-9a-f:]*$|" \
                                         "^[0-9a-f:]+:[0-9a-f:]*$|" \
-                                        "^[^\\.[:space:]]+\\.[^\\.[:space:]]+.*$|" \
                                         "^https?://[^/\\.[:space:]]+.*$|" \
                                         "^about:.*$|" \
                                         "^data:.*$|" \
                                         "^file:.*$" \
                                         ")"
 
+#define EPHY_WEB_VIEW_DOMAIN_REGEX "^localhost(\\.[^[:space:]]+)?(:\\d+)?(:[0-9]+)?(/.*)?$|" \
+                                   "^[^\\.[:space:]]+\\.[^\\.[:space:]]+.*$|"
+
 void                       ephy_web_view_set_visit_type           (EphyWebView *view, 
                                                                    EphyHistoryPageVisitType visit_type);
 EphyHistoryPageVisitType   ephy_web_view_get_visit_type           (EphyWebView *view);
@@ -65,6 +66,9 @@ GdkPixbuf *                ephy_web_view_get_snapshot             (EphyWebView
                                                                    int                        height);
 gboolean                   ephy_web_view_is_loading_homepage      (EphyWebView               *view);
 
+char*                      ephy_web_view_normalize_or_autosearch_url (EphyWebView            *view,
+                                                                      const char             *url);
+
 G_END_DECLS
 
 #endif
