@@ -158,7 +158,8 @@ gboolean                   ephy_web_view_get_is_blank             (EphyWebView
 gboolean                   ephy_web_view_has_modified_forms       (EphyWebView               *view);
 void                       ephy_web_view_get_security_level       (EphyWebView               *view,
                                                                    EphyWebViewSecurityLevel  *level,
-                                                                   char                     **description);
+                                                                   GTlsCertificate          **certificate,
+                                                                   GTlsCertificateFlags      *errors);
 void                       ephy_web_view_print                    (EphyWebView               *view);
 const char *               ephy_web_view_get_title                (EphyWebView               *view);
 const char *               ephy_web_view_get_address              (EphyWebView               *view);
