@@ -34,6 +34,7 @@ G_DEFINE_TYPE (EphyCompletionModel, ephy_completion_model, GTK_TYPE_LIST_STORE)
 
 struct _EphyCompletionModelPrivate {
   EphyHistoryService *history_service;
+  GCancellable *cancellable;
 
   EphyNode *bookmarks;
   GSList *search_terms;
@@ -72,6 +73,11 @@ ephy_completion_model_finalize (GObject *object)
     priv->search_terms = NULL;
   }
 
+  if (priv->cancellable) {
+    g_cancellable_cancel (priv->cancellable);
+    g_clear_object (&priv->cancellable);
+  }
+
   G_OBJECT_CLASS (ephy_completion_model_parent_class)->finalize (object);
 }
 
@@ -160,6 +166,9 @@ typedef struct {
   gboolean is_bookmark;
 } PotentialRow;
 
+#ifdef HAVE_WEBKIT2
+/* TODO: Favicons */
+#else
 typedef struct {
   GtkListStore *model;
   GtkTreeRowReference *row_reference;
@@ -189,6 +198,7 @@ icon_loaded_cb (GObject *source, GAsyncResult *result, gpointer user_data)
   gtk_tree_row_reference_free (data->row_reference);
   g_slice_free (IconLoadData, data);
 }
+#endif
 
 static void
 set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
@@ -196,8 +206,12 @@ set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
   GtkTreeIter iter;
   GdkPixbuf *favicon;
   GtkTreePath *path;
+#ifdef HAVE_WEBKIT2
+  /* TODO: Favicons */
+#else
   IconLoadData *data;
   WebKitFaviconDatabase* database = webkit_get_favicon_database ();
+#endif
 
   gtk_list_store_insert_with_values (GTK_LIST_STORE (model), &iter, position,
                                      EPHY_COMPLETION_TEXT_COL, row->title ? row->title : "",
@@ -208,6 +222,9 @@ set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
                                      EPHY_COMPLETION_RELEVANCE_COL, row->relevance,
                                      -1);
 
+#ifdef HAVE_WEBKIT2
+  /* TODO: Favicons */
+#else
   /* We try first with the try_get_favicon_pixbuf() because if the icon
      is in the DB it's faster than the async version. */
   favicon = webkit_favicon_database_try_get_favicon_pixbuf (database, row->location,
@@ -227,6 +244,7 @@ set_row_in_model (EphyCompletionModel *model, int position, PotentialRow *row)
   webkit_favicon_database_get_favicon_pixbuf (database, row->location,
                                               FAVICON_SIZE, FAVICON_SIZE, NULL,
                                               icon_loaded_cb, data);
+#endif
 }
 
 static void
@@ -261,10 +279,10 @@ should_add_bookmark_to_model (EphyCompletionModel *model,
     GRegex *current = NULL;
 
     for (iter = priv->search_terms; iter != NULL; iter = iter->next) {
-      current = (GRegex*) iter->data;
-      if (((title && !g_regex_match (current, title, G_REGEX_MATCH_NOTEMPTY, NULL))) &&
-          ((location && !g_regex_match (current, location, G_REGEX_MATCH_NOTEMPTY, NULL))) &&
-          ((keywords && !g_regex_match (current, keywords, G_REGEX_MATCH_NOTEMPTY, NULL)))) {
+      current = (GRegex*)iter->data;
+      if ((!g_regex_match (current, title ? title : "", G_REGEX_MATCH_NOTEMPTY, NULL)) &&
+          (!g_regex_match (current, location ? location : "", G_REGEX_MATCH_NOTEMPTY, NULL)) &&
+          (!g_regex_match (current, keywords ? keywords : "", G_REGEX_MATCH_NOTEMPTY, NULL))) {
         ret = FALSE;
         break;
       }
@@ -416,8 +434,9 @@ query_completed_cb (EphyHistoryService *service,
 
   g_free (user_data->search_string);
   g_slice_free (FindURLsData, user_data);
-
+  g_list_free_full (urls, (GDestroyNotify)ephy_history_url_free);
   g_slist_free_full (list, (GDestroyNotify)free_potential_row);
+  g_clear_object (&priv->cancellable);
 }
 
 static void
@@ -534,10 +553,16 @@ ephy_completion_model_update_for_string (EphyCompletionModel *model,
   user_data->callback = callback;
   user_data->user_data = data;
 
+  if (priv->cancellable) {
+    g_cancellable_cancel (priv->cancellable);
+    g_object_unref (priv->cancellable);
+  }
+  priv->cancellable = g_cancellable_new ();
+
   ephy_history_service_find_urls (priv->history_service,
                                   0, 0,
                                   MAX_COMPLETION_HISTORY_URLS, 0,
-                                  query, NULL,
+                                  query, priv->cancellable,
                                   (EphyHistoryJobCallback)query_completed_cb,
                                   user_data);
 }
