@@ -54,6 +54,7 @@ struct _EphyLocationControllerPrivate
 	GdkPixbuf *icon;
 	char *lock_stock_id;
 	guint editable : 1;
+	guint show_icon : 1;
 	guint show_lock : 1;
 	gboolean sync_address_is_blocked;
 };
@@ -73,6 +74,7 @@ enum
 	PROP_ADDRESS,
 	PROP_EDITABLE,
 	PROP_ICON,
+	PROP_SHOW_ICON,
 	PROP_LOCK_STOCK,
 	PROP_SHOW_LOCK,
 	PROP_WINDOW,
@@ -127,7 +129,7 @@ action_activated_cb (GtkEntryCompletion *completion,
 		if (url == NULL) return;
 
 		ephy_link_open (EPHY_LINK (controller), url, NULL,
-				ephy_link_flags_from_current_event ());
+				ephy_link_flags_from_current_event () | EPHY_LINK_TYPED);
 
 		g_free (url);
 	}
@@ -159,7 +161,7 @@ entry_activate_cb (GtkEntry *entry,
 	g_return_if_fail (address != NULL);
 
 	ephy_link_open (EPHY_LINK (controller), g_strstrip (address), NULL, 
-			ephy_link_flags_from_current_event ());
+			ephy_link_flags_from_current_event () | EPHY_LINK_TYPED);
 
 	g_free (address);
 }
@@ -220,49 +222,6 @@ sync_address (EphyLocationController *controller,
 	g_signal_handlers_unblock_by_func (widget, G_CALLBACK (user_changed_cb), controller);
 }
 
-static void
-sync_editable (EphyLocationController *controller,
-	       GParamSpec *pspec,
-	       GtkWidget *widget)
-{
-	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (widget);
-
-	gtk_editable_set_editable (GTK_EDITABLE (lentry), controller->priv->editable);
-}
-
-static void
-sync_icon (EphyLocationController *controller,
-	   GParamSpec *pspec,
-	   GtkWidget *widget)
-{
-	EphyLocationControllerPrivate *priv = controller->priv;
-	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
-
-	ephy_location_entry_set_favicon (entry, priv->icon);
-}
-
-static void
-sync_lock_stock_id (EphyLocationController *controller,
-		    GParamSpec *pspec,
-		    GtkWidget *widget)
-{
-	EphyLocationControllerPrivate *priv = controller->priv;
-	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
-
-	ephy_location_entry_set_lock_stock (entry, priv->lock_stock_id);
-}
-
-static void
-sync_show_lock (EphyLocationController *controller,
-		GParamSpec *pspec,
-		GtkWidget *widget)
-{
-	EphyLocationControllerPrivate *priv = controller->priv;
-	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (widget);
-
-	ephy_location_entry_set_show_lock (entry, priv->show_lock);
-}
-
 static char *
 get_location_cb (EphyLocationEntry *entry,
 		EphyLocationController *controller)
@@ -416,18 +375,25 @@ ephy_location_controller_constructed (GObject *object)
 	sync_address (controller, NULL, widget);
 	g_signal_connect_object (controller, "notify::address",
 				 G_CALLBACK (sync_address), widget, 0);
-	sync_editable (controller, NULL, widget);
-	g_signal_connect_object (controller, "notify::editable",
-				 G_CALLBACK (sync_editable), widget, 0);
-	sync_icon (controller, NULL, widget);
-	g_signal_connect_object (controller, "notify::icon",
-				 G_CALLBACK (sync_icon), widget, 0);
-	sync_lock_stock_id (controller, NULL, widget);
-	g_signal_connect_object (controller, "notify::lock-stock-id",
-				 G_CALLBACK (sync_lock_stock_id), widget, 0);
-	sync_show_lock (controller, NULL, widget);
-	g_signal_connect_object (controller, "notify::show-lock",
-				 G_CALLBACK (sync_show_lock), widget, 0);
+	g_object_bind_property (controller, "editable",
+				priv->location_entry, "editable",
+				G_BINDING_SYNC_CREATE);
+
+	g_object_bind_property (controller, "icon",
+				priv->location_entry, "favicon",
+				G_BINDING_SYNC_CREATE);
+
+	g_object_bind_property (controller, "show-icon",
+				priv->location_entry, "show-favicon",
+				G_BINDING_SYNC_CREATE);
+
+	g_object_bind_property (controller, "lock-stock-id",
+				priv->location_entry, "lock-stock-id",
+				G_BINDING_SYNC_CREATE);
+
+	g_object_bind_property (controller, "show-lock",
+				priv->location_entry, "show-lock",
+				G_BINDING_SYNC_CREATE);
 
 	g_signal_connect_object (widget, "activate",
 				 G_CALLBACK (entry_activate_cb),
@@ -470,6 +436,9 @@ ephy_location_controller_set_property (GObject *object,
 			}
 			priv->icon = GDK_PIXBUF (g_value_dup_object (value));
 			break;
+		case PROP_SHOW_ICON:
+			priv->show_icon = g_value_get_boolean (value);
+			break;
 		case PROP_LOCK_STOCK:
 			g_free (priv->lock_stock_id);
 			priv->lock_stock_id = g_value_dup_string (value);
@@ -483,6 +452,8 @@ ephy_location_controller_set_property (GObject *object,
 		case PROP_LOCATION_ENTRY:
 			priv->location_entry = EPHY_LOCATION_ENTRY (g_value_get_object (value));
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 	}
 }
 
@@ -506,16 +477,17 @@ ephy_location_controller_get_property (GObject *object,
 		case PROP_ICON:
 			g_value_set_object (value, priv->icon);
 			break;
+		case PROP_SHOW_ICON:
+			g_value_set_boolean (value, priv->show_icon);
+			break;
 		case PROP_LOCK_STOCK:
 			g_value_set_string (value, priv->lock_stock_id);
 			break;
 		case PROP_SHOW_LOCK:
 			g_value_set_boolean (value, priv->show_lock);
 			break;
-		case PROP_WINDOW:
-		case PROP_LOCATION_ENTRY:
-			/* not readable */
-			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 	}
 }
 
@@ -611,6 +583,19 @@ ephy_location_controller_class_init (EphyLocationControllerClass *class)
 							      GDK_TYPE_PIXBUF,
 							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
+	/**
+	* EphyLocationController:show-icon:
+	*
+	* If we should show the page icon.
+	*/
+	g_object_class_install_property (object_class,
+					 PROP_SHOW_ICON,
+					 g_param_spec_boolean ("show-icon",
+							       "Show Icon",
+							       "Whether to show the favicon",
+							       TRUE,
+							       G_PARAM_CONSTRUCT | G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+
 	/**
 	* EphyLocationController:lock-stock-id:
 	*
